Глава 3. Настройка
Пред. |  | След.

## Глава 3. Настройка

## Быстрый запуск

Для быстрого запуска радиостанции достаточно загрузить исходный код (например, клонировав репозиторий) и выполнить команду:

    ./bin/ardj config

По этой команде будут созданы конфигурационные файлы, заполненные примерами, достаточными для запуска радиостанции в минимальной конфигурации. Поддержку подкастов, выгрузку плей-листа в Last.fm, связь с конференцией Jabber и другие функции всё равно придётся настраивать вручную, но само вещание должно работать с автоматически созданными файлами. Для запуска всех компонентов ardj используйте следующую команду:

    ./bin/ardj server

По этой команде будут запущены все компоненты ardj. Если каких-то компонентов в системе недостаёт — будет выдано сообщение и процесс прервётся. Если же все компоненты доступны — начнётся вещание встроенной музыки (в комплекте ПО есть несколько свободно распространяемых музыкальных файлов). При аварийном завершении любого компонента (icecast, ezstream и т.п.), он будет автоматически перезапущен.

Если всё прошло хорошо и основные компоненты самонастроились, будет выведен URL потока, по которому можно слушать вещание новой станции. Процесс можно прервать и перезапустить в любой момент (рекомендуется это делать после редактирования конфигурационных файлов). Если какой-то компонент постоянно перезапускается, следует посмотреть в лог ошибок, который есть в папке `~/.ardj` (например, `~/.ardj/icecast2.log`).

Пред. |  | След.
Глава 2. Установка | Начало | Настройка синтезатора речи